==> lbdevmanager-0.1.1.tar.gz: lbdevmanager-0.1.1/lbdevmanager/YamlManager.py <==
###############################################################################
# (c) Copyright 2017 CERN                                                     #
#                                                                             #
# This software is distributed under the terms of the GNU General Public      #
# Licence version 3 (GPL Version 3), copied verbatim in the file "COPYING".   #
#                                                                             #
# In applying this licence, CERN does not waive the privileges and immunities #
# granted to it by virtue of its status as an Intergovernmental Organization  #
# or submit itself to any jurisdiction.                                       #
###############################################################################
'''
Module that manages the DEV install area on /cvmfs/lhcbdev.cern.ch/lib

@author: Ben Couturier & Stefan-Gabriel CHITIC
'''
import os
import logging
import yaml
from pykwalify.core import Core
from pykwalify.errors import SchemaError


class YamlManager:

    def __init__(self, configFile):
        self.log = logging.getLogger(__name__)
        self.log.setLevel(logging.DEBUG)
        self.configfile = configFile
        if not os.path.exists(self.configfile):
            raise Exception("Could not find config file %s" %
                            self.configfile)

    def loadConfig(self):
        ''' Just load the YAML config file '''
        with open(self.configfile) as f:
            config = yaml.load(f)
            return config

    def getPrefixList(self):
        ''' Get the list of LCG packages to install '''
        config = self.loadConfig()
        prefixlist = []
        for p in config["packages"]:
            name = p["name"]
            for lcg in p["LCG"]:
                for v in p["versions"]:
                    prefix = "LCG_%s_%s_%s" % (lcg, name, v)
                    self.log.info("Looking for %s" % prefix)
                    prefixlist.append(prefix)
        return prefixlist

    def validateYAML(self):
        ''' Validates the yaml config file against the used schema '''
        script_dir = os.path.dirname(os.path.realpath(__file__))
        schema_file = os.path.join(script_dir, 'schema.yaml')
        self.log.warning("Using schema file %s" % schema_file)
        c = Core(source_file=self.configfile, schema_files=[schema_file])
        try:
            c.validate(raise_exception=True)
            return True
        except SchemaError as e:
            self.log.error("There was a problem validating with the file %s:"
                           "%s" % (self.configfile, str(e)))
            return False

==> lbdevmanager-0.1.2.tar.gz: lbdevmanager-0.1.2/lbdevmanager/YamlManager.py <==
###############################################################################
# (c) Copyright 2017 CERN                                                     #
#                                                                             #
# This software is distributed under the terms of the GNU General Public      #
# Licence version 3 (GPL Version 3), copied verbatim in the file "COPYING".   #
#                                                                             #
# In applying this licence, CERN does not waive the privileges and immunities #
# granted to it by virtue of its status as an Intergovernmental Organization  #
# or submit itself to any jurisdiction.                                       #
###############################################################################
'''
Module that manages the DEV install area on /cvmfs/lhcbdev.cern.ch/lib

@author: Ben Couturier & Stefan-Gabriel CHITIC
'''
import os
import logging
import yaml
from pykwalify.core import Core
from pykwalify.errors import SchemaError
import re

class YamlManager:

    def __init__(self, configFile, exclusionFile):
        self.log = logging.getLogger(__name__)
        self.log.setLevel(logging.DEBUG)
        self.configfile = configFile
        self.exclusionFile = exclusionFile
        if not os.path.exists(self.configfile):
            raise Exception("Could not find config file %s" %
                            self.configfile)

    def loadConfig(self):
        ''' Just load the YAML config file '''
        with open(self.configfile) as f:
            config = yaml.load(f)
            return config

    def loadExclusion(self):
        exclusion_list = []
        with open(self.exclusionFile) as f:
            for l in f.readlines():
                if re.match("^\s*#", l):
                    continue
                else:
                    exclusion_list.append(re.compile(l.rstrip()))
        return exclusion_list

    def getPrefixList(self):
        ''' Get the list of LCG packages to install '''
        config = self.loadConfig()
        prefixlist = []
        for p in config["packages"]:
            name = p["name"]
            for lcg in p["LCG"]:
                for v in p["versions"]:
                    prefix = "LCG_%s_%s_%s" % (lcg, name, v)
                    self.log.info("Looking for %s" % prefix)
                    prefixlist.append(prefix)
        exclusionlist = self.loadExclusion()
        return (prefixlist, exclusionlist)

    def validateYAML(self):
        ''' Validates the yaml config file against the used schema '''
        script_dir = os.path.dirname(os.path.realpath(__file__))
        schema_file = os.path.join(script_dir, 'schema.yaml')
        self.log.warning("Using schema file %s" % schema_file)
        c = Core(source_file=self.configfile, schema_files=[schema_file])
        try:
            c.validate(raise_exception=True)
            return True
        except SchemaError as e:
            self.log.error("There was a problem validating with the file %s:"
                           "%s" % (self.configfile, str(e)))
            return False
